==> godot-3.2.2-beta1.tar.xz: godot-3.2.2-beta1/DONORS.md <==
# Donors to the Godot Engine project

Godot Engine is a non-profit project developed by a community of voluntary
contributors, as well as occasional paid contributors thanks to the financial
support of generous donors.

The ways to donate to the project, as well as details on how the funds are
used, are described on [Godot's website](https://godotengine.org/donate).

The following is a list of the current monthly donors, to be have their
generous deed immortalized in the next stable release of Godot Engine.

## Platinum sponsors

    Heroic Labs <https://heroiclabs.com>
    Interblock <http://interblockgaming.com>

## Gold sponsors

    Gamblify <https://www.gamblify.com>
    Moonwards <https://www.moonwards.com>

## Mini sponsors

    AD Ford
    Alan Beauchamp
    Anand Mallik
    Andres Hernandez
    Andrew Dunai
    Brandon Lamb
    Christian Baune
    Christopher Montesano
    Darkhan Baimyrza
    Darrin Massena
    Dov Zimring
    Edward Flick
    Gamechuck
    GameDev.net
    GameDev.tv
    Grady
    Hein-Pieter van Braam
    Jacob McKenney
    Jasper Brooks
    Javary Co.
    Jeffery Chiu
    Justin Arnold
    Justo Delgado Baudí
    Kyle Szklenski
    Matthieu Huvé
    Maxim Karsten
    Mike King
    Nathan Warden
    Neal Gompa (Conan Kudo)
    Péter Magyar
    Slobodan Milnovic
    Stephan Lanfermann
    Steve
    Tristan Pemble
    VilliHaukka

## Gold donors

    Andrei
    Dave
    David Gehrig
    David Graham
    David Snopek
    Ed Morley
    Florian Krick
    Florian Rämisch
    Jakub Grzesik
    Manuele Finocchiaro
    Officine Pixel S.n.c.
    Ronan Zeegers
    Sofox
    Taylor Ritenour
    Zaven Muradyan

    Asher Glick
    Austen McRae
    Bernhard Werner
    beVR
    Carlo Cabanilla
    Daniel James
    David Giardi
    Default Name
    eggs
    Felix Bohmann
    Florian Breisch
    Gamejunkey
    Javier Roman
    Jay Horton
    Jon Woodward
    Karl Werf
    Keinan Powers
    Klavdij Voncina
    Lex Steers
    Luke
    Maciej Pendolski
    Matthew Hillier
    Mohamed Ikbel Boulabiar
    Mored4u
    Retro Village
    Rob Messick
    Ryan Badour
    Sandro Jenny
    Scott Wadden
    Sergey
    thechris
    Tom Langwaldt
    Tricky Fat Cat
    tukon
    William Wold

    Alex Khayrullin
    alice gambrell
    Chris Goddard
    Chris Serino
    Christian Padilla
    Conrad Curry
    Craig Smith
    Darrian Little
    Horváth Péter
    Ivan Trombley
    Jakub Dering
    Joan Fons
    Joshua Flores
    Krzysztof Jankowski
    Lord Bloodhound
    Pascal Grüter
    Petr Malac
    Rami
    Reneator
    Rob
    Robert Willes
    Ronnie Ashlock
    SKison
    Thomas Bjarnelöf
    Unseen Domains
    Valryia
    Vincent Henderson
    Wojciech Chojnacki
    Xavier PATRICELLI

    Adam Nakonieczny
    Adam Neumann
    Alexander J Maynard
    Alexey Dyadchenko
    Alex Z
    Andreas Funke
    André Frélicot
    aoshiwik
    Ben Powell
    Carlos de Sousa Marques
    Charlie Whitfield
    Chase Taranto
    Chris Petrich
    Christian Alexander Bjørklund Bøhler
    Christian Leth Jeppesen
    Christoph Schröder
    Cody Parker
    Coldragon
    Craig Ostrin
    D
    Daniel Eichler
    David White
    Denis Janßen
    Easypete
    Eric Monson
    ethan ball
    Eugenio Hugo Salgüero Jáñez
    Fain
    flesk
    Gary Hulst
    gavlig
    GGGames.org
    Green Fox
    Guilherme Felipe de C. G. da Silva
    Halom Vered
    Heath Hayes
    Idzard Kwadijk
    Isaac Clausman
    Jared White
    Jeff Nyte
    Jeremy Sims
    Jerry Ling
    Joe Flood
    John G Gentzel
    Jon Hermansen
    Jose Malheiro
    Joshua Lesperance
    Juan Velandia
    Juraj Móza
    Kelteseth
    kinfox
    Marcelo Dornbusch Lopes
    Markus Fehr
    Markus Wiesner
    Martin Eigel
    Matt Eunson
    Max Bulai
    m kaersten
    MuffinManKen
    Nick Nikitin
    Oliver Dick
    Oscar Campos
    Patrick Ting
    Paul Hocker
    Paul Von Zimmerman
    Pete Goodwin
    pl
    Ranoller
    Robert Larnach
    Rocknight Studios
    Romildo Franco
    Ryan
    Samuel Judd
    Scott Pilet
    Sean Morgan
    Serban Serafimescu
    Sindre Sømme
    SleepCircle
    spilldata
    Steve Hyatt
    Stoned Xander
    TheLevelOfDetail .
    Thomas Krampl
    Thomas Kurz
    Tobias Bocanegra
    Urho
    William Foster
    Zhou Tuizhi
    Zie Weaver
    蕭惟允

## Silver donors

    1D_Inc
    Abraham Haskins
    Adam
    Adam Brunnmeier
    Adam  Carr
    Adam Long
    Adam McCurdy
    Adam Netzel
    Adam N Webber
    Adam Smeltzer
    Adam Szymański
    Adisibio
    Adrian Demetrescu
    Agustinus Arya
    Aidan O'Flannagain
    Aki Mimoto
    Alan Mervitz
    Alan Stice
    Albin Jonasson Svärdsby
    Alder Stefano
    AleMax
    Alessandro Senese
    Alexander Erlemann
    alex clavelle
    Allan Davis
    Allen Schade
    Andreas Evers
    Andreas Krampitz
    André Simões
    Andrew Thomas
    Anthony Avina
    Anthony Staunton
    AP Condomines
    Arda Erol
    Armin Preiml
    Arseniy M
    Arthur S. Muszynski
    Asger
    Ashley Claymore
    Aubrey Falconer
    Avencherus
    B A
    Balázs Batári
    Benedikt
    Ben G
    Ben Phelan
    Ben Vercammen
    Bernd Jänichen
    Bjarne
    Black Block
    Blair Allen
    Bobby CC Wong
    brian
    bugcaptor
    Burney Waring
    Cameron Meyer
    Carlo Sitaro
    Carl van der Geest
    Carwyn Edwards
    Cassidy James
    Chris Brown
    Chris Chapin
    Christian Winter
    Christoffer Sundbom
    Christoph Brodmann
    Christophe Gagnier
    Christopher Schmitt
    Christoph Woinke
    Clay Heaton
    Curt King
    Daniel Johnson
    Daniel Kimblad
    Daniel Pontillo
    David May
    David Woodard
    DiCola Jamn
    Dominic Cooney
    Dominik Wetzel
    Donn Eddy
    Donovan Hutcheon
    Dragontrapper
    Dr Ewan Murray
    Duobix
    Duodecimal
    Dylan Todd
    Eduardo Teixeira
    Edward Herbert
    Edward Moulsdale
    Edward Swartz
    Egon Elbre
    Elias Nykrem
    Elmeri '- Duy Kevin Nguyen
    Ephemeral
    Eric Ellingson
    Eric Rogers
    Eric Williams
    Erkki Seppälä
    Evan Rose
    Fancy Ants Studios
    Fekinox
    Felix Kollmann
    Flaredown
    Forty Doubleu
    FuDiggity
    Gadzhi Kharkharov
    gamedev by Celio
    Gary Thomas
    George Marques
    GiulianoB
    Greg Olson
    GREGORY C FEIN
    Greg P
    Greyson Richey
    Grid
    Guldoman
    Hal A
    Heribert Hirth
    Hunter Jones
    Hylpher
    Ichiro Dohi
    Iiari
    iKlem
    IndustrialRobot
    Jacob
    Jaiden Gerig
    Jaime Ruiz-Borau Vizárraga
    Jako Danar
    James A F Manley
    Janders
    Jannik Gröger
    JARKKO PARVIAINEN
    Jeff Hungerford
    Jennifer Graves
    Jeremy Kahn
    Jesse Dubay
    Joel Fivat
    Joel Höglund
    Joel Setterberg
    Johannes Wuensch
    John Gabriel
    Jomei Jackson
    Jonas Bernemann
    Jonas Rudlang
    Jonas Yamazaki
    Jonatan R
    Jonathan G
    Jonathon
    Jon Bonazza
    Jon Sully
    Jorge Caballero
    Jose Aleman
    Jose C. Rubio
    Joseph Catrambone
    Juanfran
    Judd
    Julian Murgia
    JungleRobba
    Justin Hamilton
    Justin Spedding
    KaDokta
    Kauzig
    Keedong Park
    Keith Bradner
    Kevin McPhillips
    kickmaniac
    Kiri Jolly
    Kiyohiro Kawamura (kyorohiro)
    Kjetil Haugland
    Klagsam
    KR McGinley
    KsyTek Games
    Kuan Cheang
    kycho
    Kyle Appelgate
    Laurent Tréguier
    Leonardo Dimano
    Levi Lindsey
    Lin Chear
    Linus Lind Lundgren
    Lionel Gaillard
    Luigi Renna
    LunaticInAHat
    Lurkars
    Major Haul
    Malcolm
    Malik Ahmed
    Malik Nejer
    Markus Michael Egger
    Martin Holas
    Martin Liška
    Marvin
    Mathieu Rimelen
    Matt Edwards
    Matthew Little
    Matti Pohjanvirta
    Maxime Blade
    Maxwell
    medecau
    Megasploot
    Melissa Mears
    mewin
    mhilbrunner
    Michael Dürwald
    Michael Haney
    Michael Labbe
    Michał Skwarek
    Mikael Olsson
    Mikayla
    Mike Birkhead
    Mike Cunningham
    Mitchell J. Wagner
    MoM
    Nathan Fish
    Natrim
    nee
    Neil Blakey-Milner
    Neil Wang
    Nerdforge
    Nicholas
    Nicholas Girga
    Nick Macholl
    Nicolás Montaña
    Nicolas SAN AGUSTIN
    Nima Farid
    NZ
    Oleg Reva
    Olivier
    Omar Delarosa
    Oscar Norlander
    Pan Ip
    Patrick Nafarrete
    Paul Gieske
    Paul Mason
    Paweł Kowal
    Pedro Assuncao
    Penguin
    Petrus Prinsloo
    Philip Cohoe
    Point08
    Rad Cat
    Rafa Laguna
    rainerLinux
    Raphael Leroux
    Remi Rampin
    Rémi Verschelde
    Ricardo Alcantara
    Richard Diss
    Richard Ivánek
    Robert Farr (Larington)
    Robert Hernandez
    Roberto Sánchez
    Roger Smith
    Roland Rząsa
    Roman Tinkov
    Ronald Ho Hip (CrimsonZA)
    Ronan
    Ryan Groom
    Ryan Hentz
    Sam.C
    Sam Edson
    Samuele Zolfanelli
    Sasori Olkof
    Scott D. Yelich
    Scott Longley
    Sebastian Michailidis
    Sebastian Vetter
    Sergio Mello-Grand
    sgnsajgon
    Shane
    Shane Sicienski
    Shane Spoor
    Siim Raidma
    Simon Wenner
    SK
    smbe19
    smo1704
    Stefano Caronia
    Svenne Krap
    Terry
    tezuvholovdr
    thomas
    Thomas Bechtold
    Thomas Detoy
    Thomas Kelly
    Tim Drumheller
    Timothy B. MacDonald
    tinyBigGames LLC
    Title Plinsut
    Tobbun
    Tom Glenn
    Torgeir Lilleskog
    Torsten Crass
    Travis O'Brien
    Trent Skinner
    Troy Bonneau
    Tryggve Sollid
    Turgut Temucin
    Tyler Compton
    Tyler Stafos
    UltyX
    Vaughan Ling
    Victor
    Vigilant Watch
    Vincent Cloutier
    waka nya
    Wayne Haak
    werner mendizabal
    Wiley Thompson
    Will
    William Hogben
    Wyatt Goodin
    Yegor
    Yuri Sizov

## Bronze donors

There are even more donors that support the project with a small monthly donation.
Every bit counts and we thank every one of them for their amazing support!

==> godot-3.2.3-beta1.tar.xz: godot-3.2.3-beta1/DONORS.md <==
# Donors to the Godot Engine project

Godot Engine is a non-profit project developed by a community of voluntary
contributors, as well as occasional paid contributors thanks to the financial
support of generous donors.

The ways to donate to the project, as well as details on how the funds are
used, are described on [Godot's website](https://godotengine.org/donate).

The following is a list of the current monthly donors, to be have their
generous deed immortalized in the next stable release of Godot Engine.

## Platinum sponsors

    Heroic Labs <https://heroiclabs.com>
    Interblock <http://interblockgaming.com>

## Gold sponsors

    Gamblify <https://www.gamblify.com>
    Moonwards <https://www.moonwards.com>

## Mini sponsors

    AD Ford
    Alan Beauchamp
    albinaask
    Alejandro Saucedo
    Andrew Dunai
    Brandon Lamb
    Christian Baune
    Christopher Montesano
    Darkhan Baimyrza
    Darrin Massena
    Digital Grows
    Dov Zimring
    Edward Flick
    Gamechuck
    GameDev.net
    Grady
    Hein-Pieter van Braam
    Jacob McKenney
    Jasper Brooks
    Javary Co.
    Jeffery Chiu
    Justin Arnold
    Kyle Szklenski
    Marcel Kräml
    Matthieu Huvé
    Maxim Karsten
    Mike King
    Nathan Warden
    Neal Gompa (Conan Kudo)
    Ronnie Cheng
    Slobodan Milnovic
    Stephan Lanfermann
    Steve
    Tristan Pemble
    VilliHaukka

## Gold donors

    Bjarke
    David Gehrig
    David Snopek
    Ed Morley
    Florian Rämisch
    Jakub Grzesik
    Manuele Finocchiaro
    Officine Pixel S.n.c.
    Rami
    Ronan Zeegers
    Sofox
    Spicylewd
    Taylor Ritenour
    Zaven Muradyan

    Andreas Schüle
    Andres Hernandez
    Asher Glick
    Austen McRae
    Bernhard Werner
    beVR
    Carlo Cabanilla
    Christopher Case
    Daniel James
    David Giardi
    Default Name
    eggs
    Florian Breisch
    Forge
    Gamejunkey
    Javier Roman
    Jon Woodward
    Karl Werf
    Klavdij Voncina
    Lex Steers
    Luke
    Maciej Pendolski
    Matthew Hillier
    Mohamed Ikbel Boulabiar
    Monster Vial
    Rene
    Retro Village
    Rob Messick
    Roland Fredenhagen
    Ryan Badour
    Sandro Jenny
    Sarksus
    Scott Wadden
    Sergey
    thechris
    Tom Langwaldt
    Tricky Fat Cat
    tukon
    William Wold

    Alex Khayrullin
    alice gambrell
    Andrew Harris
    Barugon
    Chris Goddard
    Chris Serino
    Christian Padilla
    Conrad Curry
    Craig Smith
    Darrian Little
    dragonage13
    GiulianoB
    Hoai Nam Tran
    Horváth Péter
    Jeff Nyte
    Joan Fons
    Joshua Flores
    Leo Fidel R Liban
    Michael Dürwald
    Péter Magyar
    Petr Malac
    Rob
    Robert Willes
    Ronnie Ashlock
    SKison
    Thomas Bjarnelöf
    Valryia
    Vincent Henderson
    Vojtěch
    Wojciech Chojnacki
    Xavier PATRICELLI
    Zoran Kukulj

    Adam Nakonieczny
    Adam Neumann
    Alexander J Maynard
    Alexey Dyadchenko
    Andreas Funke
    André Frélicot
    aoshiwik
    Ben Powell
    Carlos de Sousa Marques
    Charlie Whitfield
    Chase Taranto
    Chelsea Hash
    Chris Petrich
    Christian Alexander Bjørklund Bøhler
    Christian Leth Jeppesen
    Cody Parker
    Craig Ostrin
    curtis Kramer
    D
    Dev To be curious
    Digital Denizen
    Easypete
    Edgar Sun
    Eugenio Hugo Salgüero Jáñez
    flesk
    F S
    Gary Hulst
    gavlig
    GGGames.org
    Guilherme Felipe de C. G. da Silva
    Heath Hayes
    Hu Hund
    Isaac Clausman
    Jared White
    Joe Flood
    John G Gentzel
    Jose Malheiro
    Joseph Crane
    Joshua Lesperance
    Juan Velandia
    Julian Todd
    Juraj Móza
    Justo Delgado Baudí
    Kelteseth
    kickmaniac
    kinfox
    Lain Ballard
    luca duran
    Marcelo Dornbusch Lopes
    Marcelo Henrique Gonçalves
    Markus Fehr
    Markus Wiesner
    Martin Eigel
    Matt Eunson
    Mikado069
    m kaersten
    MuffinManKen
    Nick Abousselam
    Oliver Dick
    Oscar Campos
    Patrick Ting
    Paul Hocker
    Paul Von Zimmerman
    Pete Goodwin
    PhaineOfCatz
    pl
    Ranoller
    Rob McInroy
    Rocknight Studios
    Ryan
    Samuel Judd
    Scott Pilet
    Scott Ryan-Taylor
    Sean Morgan
    Sean Robertson
    Sébastien
    Serban Serafimescu
    SleepCircle
    spilldata
    Stoned Xander
    Tahiti Bos
    TheLevelOfDetail .
    Thomas Kurz
    Tobias Bocanegra
    Trent Fehl
    Urho
    William Foster
    Zhou Tuizhi
    Zie Weaver
    蕭惟允

## Silver donors

    1D_Inc
    Aaron
    Aaron Winter
    Abel Crunk
    Abraham Haskins
    Acheron
    Adam
    Adam Brunnmeier
    Adam  Carr
    Adam Long
    Adam McCurdy
    Adam Netzel
    Adam N Webber
    Adam Smeltzer
    Adam Szymański
    Adisibio
    Agustinus Arya
    Aidan O'Flannagain
    Aki Mimoto
    Albin Jonasson Svärdsby
    Alder Stefano
    AleMax
    Alessandro Senese
    Alexander Erlemann
    alex clavelle
    Allan Davis
    Allen Schade
    Andreas Krampitz
    André Simões
    andrew james morris
    Andrew Mansuetti
    Andrew Thomas
    Ano Nim
    Anthony Avina
    AP Condomines
    Arda Erol
    Armin Preiml
    Arseniy M
    Arthur S. Muszynski
    Ashley Claymore
    Ashton Scott Snapp
    Aubrey Falconer
    B A
    Balázs Batári
    Balázs Hasprai
    Bartosz Bielecki
    Benedikt
    Ben Vercammen
    Bernd Jänichen
    Bjarne
    Black Block
    Blair Allen
    Bobby CC Wong
    Bram
    brian
    Burney Waring
    Cameron Meyer
    Carl van der Geest
    Carwyn Edwards
    Cas Brugman
    Cassidy James
    Chris Brown
    Chris Chapin
    Christian Winter
    Christoffer Sundbom
    Christoph Brodmann
    Christophe Gagnier
    Christopher Schmitt
    Christoph Woinke
    Clay Heaton
    Cole Johnson
    Cuauhtemoc Moreno
    Curt King
    Daniel Kimblad
    Daniel Johnson
    DanielMaximiano
    Daniel Tebbutt
    Dave Walker
    David May
    David Woodard
    Dimitri Stanojevic
    Dmytro Korchynskyi
    Dominik Wetzel
    Donn Eddy
    Dragontrapper
    Dr Ewan Murray
    Dr.Raccoon
    Duobix
    Duodecimal
    Eduardo Teixeira
    Edward Herbert
    Edward Swartz
    Eelco F Hillenius
    Egon Elbre
    Elgenzay
    Elias Nykrem
    Ephemeral
    Eric Ellingson
    Eric Williams
    Erkki Seppälä
    Evan Rose
    Fain
    Faisal Alkubaisi
    Fancy Ants Studios
    Fekinox
    Felix Bohmann
    Flaredown
    Florian Richer
    Forty Doubleu
    Frank
    FuDiggity
    Gadzhi Kharkharov
    gamedev by Celio
    Gary Thomas
    George Marques
    Greg Olson
    GREGORY C FEIN
    Greyson Richey
    Grid
    Guillaume Audirac
    Guillaume Pham Ngoc
    Guldoman
    Gustavo Loureiro dos Reis
    Hal A
    Heribert Hirth
    Hunter Jones
    Hylpher
    Iiari
    iKlem
    IndustrialRobot
    Ivan Nikolaev
    Jackson Harmer
    Jacob
    Jaguar
    Jaiden Gerig
    Jaime Ruiz-Borau Vizárraga
    Jako Danar
    James A F Manley
    Jamiee H
    Jamie Massey
    Janders
    JARKKO PARVIAINEN
    Jean-Baptiste LEPESME
    Jeff Hungerford
    Jennifer Graves
    Jesse Dubay
    Joe Alden
    Joel Fivat
    Joel Höglund
    Joel Setterberg
    Johannes Goslar
    John Gabriel
    John Walker
    Jomei Jackson
    Jonas
    Jonas Bernemann
    Jonas Rudlang
    Jonas Yamazaki
    Jonatan R
    Jonathan G
    Jon Bonazza
    Jon Sully
    Jordy Goodridge
    Jorge Antunes
    Jose Aleman
    Jose C. Rubio
    Joseph Catrambone
    Josh Mitchell
    Joshua Southerland
    Juanfran
    Judd
    Julian Murgia
    June Little
    JungleRobba
    Justin Calleja
    Justin Hamilton
    Justin Spedding
    KaDokta
    Karel Němec
    Kauzig
    Keedong Park
    Keith Bradner
    Kent Jofur
    Kevin McPhillips
    Kevin Velasco
    Kiri Jolly
    Kjetil Haugland
    Klagsam
    KsyTek Games
    Kuan Cheang
    kycho
    Kyle Appelgate
    Kyuppin
    Laurent Tréguier
    Leonardo Dimano
    Lin Chear
    Linus Lind Lundgren
    Lionel Gaillard
    Luigi Renna
    LunaticInAHat
    Lurkars
    Major Haul
    Malcolm
    Marco Lardelli
    Mark Jad
    Mark Krenz
    Markus Michael Egger
    Martin FIbik
    Martin Holas
    Martin Linklater
    Martin Liška
    Martin Trbola
    Marvin
    Mathieu
    Matt Edwards
    Mauro Pellegrini
    Max Fiedler
    Maxime Blade
    Maxwell
    Megasploot
    Melissa Mears
    mewin
    Michael Haney
    Michał Skwarek
    Mikael Olsson
    Mikayla
    Mike Birkhead
    Mike Cunningham
    Molinghu
    MoM
    Mored4u
    Nathan Fish
    Natrim
    nee
    Neil Blakey-Milner
    Neil Wang
    Nerdforge
    Nerdyninja
    Nicholas
    Nicholas Girga
    Nick Allen
    Nick Macholl
    Niclas Eriksen
    Nicolás Montaña
    Nicolas SAN AGUSTIN
    NZ
    Oleg Reva
    Olivier
    Omar Delarosa
    Oscar Norlander
    Pan Ip
    Parinya Teerakasemsuk
    Patrick Dully
    Patrick Nafarrete
    Paul Gieske
    Paul Mason
    Paweł Kowal
    Pedro Assuncao
    Penguin
    Peter
    Philip Cohoe
    Piotr Góral
    Point08
    pwab
    Rad Cat
    Rafa Laguna
    Ram
    Remi Rampin
    Rémi Verschelde
    Reneator
    Ricardo Alcantara
    Richard Diss
    Richard Ivánek
    Robert Farr (Larington)
    Robert Larnach
    Roger Smith
    Roland Rząsa
    Roman Tinkov
    Ronald Ho Hip (CrimsonZA)
    Ronan
    Ronny Mühle
    Ryan Groom
    Sam Edson
    Samuele Zolfanelli
    Scott D. Yelich
    Scott Longley
    ScottMakesGames
    Sebastian Michailidis
    Sebastian Vetter
    Sergio Mello-Grand
    Shane
    Shane Sicienski
    Shane Spoor
    Shiomi '- Duy Kevin Nguyen
    Siim Raidma
    Simon Jonas Larsen
    Simon Wenner
    Sintinium
    SK
    smbe19
    smo1704
    soft circles
    Squirrel
    Stefano Caronia
    Steve Cloete
    Svenne Krap
    Taylor Fahlman
    Terry
    tezuvholovdr
    TheVoiceInMyHead
    thomas
    Thomas Bechtold
    Thomas Detoy
    Thomas Kelly
    Tim Drumheller
    Tim Erskine
    Timothy B. MacDonald
    Title Plinsut
    Tobbun
    Tobias Bradtke
    Tom Glenn
    Toni Duran
    Torgeir Lilleskog
    Torsten Crass
    Travis O'Brien
    Trent Skinner
    Troy Bonneau
    Tryggve Sollid
    Turgut Temucin
    Tyler Compton
    Tyler Stafos
    UltyX
    Valentí Gàmez
    Vaughan Ling
    Victor
    Vigilant Watch
    Vincent Cloutier
    Vladimir Savin
    waka nya
    Wayne Haak
    werner mendizabal
    Wiley Thompson
    Will
    Wyatt Goodin
    Yegor Smirnov
    YiYin Gu
    Yuri LaPointe
    Yuri Sizov
    Zgegnesh Hemomancer
    郝晨煜

## Bronze donors

There are even more donors that support the project with a small monthly donation.
Every bit counts and we thank every one of them for their amazing support!
